@@ -66,6 +66,7 @@ var (
 	goarch      = runtime.GOARCH
 	goos        = runtime.GOOS
 	hostCC      string
+	nogcc       = goos == "windows" && goarch == "arm64" // We have no 32b mingw-gcc binary targeting windows/amd64 bit yet.
 	re          *regexp.Regexp
 	target      = fmt.Sprintf("%s/%s", goos, goarch)
 	totalMemory = memory.TotalMemory()
@@ -300,6 +301,10 @@ func shell(echo bool, cmd string, args ...string) ([]byte, error) {
 }
 
 func TestExec(t *testing.T) {
+	if nogcc {
+		t.Skip()
+	}
+
 	g := newGolden(t, fmt.Sprintf("testdata/test_exec_%s_%s.golden", runtime.GOOS, runtime.GOARCH))
 
 	defer g.close()
@@ -764,6 +769,10 @@ func (g *golden) close() {
 }
 
 func TestCSmith(t *testing.T) {
+	if nogcc {
+		t.Skip()
+	}
+
 	abi, err := cc.NewABI(runtime.GOOS, runtime.GOARCH)
 	if err != nil {
 		t.Fatal(err)
@@ -843,6 +852,11 @@ func TestCSmith(t *testing.T) {
 		"-s 4101947480",
 	}
 
+	// Other blacklist
+	blacklist := []struct{ target, seed string }{
+		{"linux/ppc64le", "8032246412188002"}, // gcc 10.2.1 bug.
+	}
+
 	fixedBugs := []string{
 		"--bitfields --max-nested-struct-level 10 --no-const-pointers --no-consts --no-packed-struct --no-volatile-pointers --no-volatiles --paranoid -s 1110506964",
 		"--bitfields --max-nested-struct-level 10 --no-const-pointers --no-consts --no-packed-struct --no-volatile-pointers --no-volatiles --paranoid -s 1338573550",
@@ -886,6 +900,7 @@ func TestCSmith(t *testing.T) {
 		"--max-nested-struct-level 10 --no-const-pointers --no-consts --no-packed-struct --no-volatile-pointers --no-volatiles --paranoid --bitfields -s 1701143130",
 		"--max-nested-struct-level 10 --no-const-pointers --no-consts --no-packed-struct --no-volatile-pointers --no-volatiles --paranoid --bitfields -s 20004725738999789",
 		"--max-nested-struct-level 10 --no-const-pointers --no-consts --no-packed-struct --no-volatile-pointers --no-volatiles --paranoid --bitfields -s 3654957324",
+		"--max-nested-struct-level 10 --no-const-pointers --no-consts --no-packed-struct --no-volatile-pointers --no-volatiles --paranoid --bitfields -s 8032246412188002",
 		"--no-bitfields --max-nested-struct-level 10 --no-const-pointers --no-consts --no-packed-struct --no-volatile-pointers --no-volatiles --paranoid -s 1302111308",
 		"--no-bitfields --max-nested-struct-level 10 --no-const-pointers --no-consts --no-packed-struct --no-volatile-pointers --no-volatiles --paranoid -s 3285852464",
 		"--no-bitfields --max-nested-struct-level 10 --no-const-pointers --no-consts --no-packed-struct --no-volatile-pointers --no-volatiles --paranoid -s 3609090094",
@@ -907,6 +922,7 @@ out:
 		switch {
 		case i < len(fixedBugs):
 			s := fixedBugs[i]
+			trc("", s)
 			if re != nil && !re.MatchString(s) {
 				continue
 			}
@@ -918,6 +934,11 @@ out:
 					}
 				}
 			}
+			for _, v := range blacklist {
+				if v.target == target && strings.Contains(s, v.seed) {
+					continue out
+				}
+			}
 
 			args += fixedBugs[i]
 			a := strings.Split(s, " ")
